@@ -39,11 +39,14 @@ extern "C" {
     void _solexa_to_IUPAC(char *linebuf);
     void _as_factor_SEXP(SEXP vec, SEXP lvls);
     void _as_factor(SEXP vec, const char **levels, const int n_lvls);
-    double _count_lines_sum(SEXP files);
-    SEXP count_lines(SEXP files);
     SEXP count_ipar_int_recs(SEXP files);
     SEXP _get_SEXP(SEXP from, SEXP rho, const char *with);
 
+/* count.c */
+    double _count_lines_sum(SEXP files);
+    SEXP count_lines(SEXP files);
+    SEXP count_records(SEXP file);
+
 /* xstring_util.c */
 
     typedef SEXP _XSnap;
